# Maintainer: artist for Artix Linux
# suppress extraneous messages from Moksha Desktop 
export EINA_LOG_LEVEL=0
export EINA_LOG_LEVELS=e:0
export EINA_LOG_BACKTRACE=0
export EINA_LOG_LEVEL_MAXIMUM=0
